@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2012-2018, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2012-2019, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -303,7 +303,7 @@ protected:
 
  public:
     PhylipExport() : _mpopi(NULL), _site_index(0) {}
-    int open(const MetaPopInfo *mpopi);
+    int  open(const MetaPopInfo *mpopi);
     int  write_header();
     int  post_processing();
     void close();
@@ -323,6 +323,45 @@ class PhylipFixedExport: public PhylipExport {
     int write_site(const CSLocus* cloc, const LocPopSum* psum, Datum const*const* datums, size_t col, size_t index);
 };
 
+class PhylipVarAllExport: public Export {
+    const MetaPopInfo *_mpopi;
+    string   _log_path;
+    ofstream _logfh;
+    ofstream _parfh;
+    string   _partition_path;
+
+    size_t _seq_len;
+    size_t _site_index;
+    size_t _loc_cnt;
+    map<int, string> _outstrs;
+    
+public:
+    PhylipVarAllExport() : _mpopi(NULL), _seq_len(0), _site_index(1), _loc_cnt(1) {}
+    int  open(const MetaPopInfo *mpopi);
+    int  write_header();
+    int  write_batch(const vector<LocBin *> &);
+    int  post_processing();
+    void close();
+};
+
+class HzarExport: public OrderableExport {
+    const MetaPopInfo *_mpopi;
+    ofstream _tmpfh;
+    string   _tmp_path;
+    ifstream _intmpfh;
+
+ public:
+    HzarExport() : _mpopi(NULL) {}
+    ~HzarExport() {}
+    int  open(const MetaPopInfo *mpopi);
+    int  write_header() { return 0; };
+    int  post_processing();
+    void close();
+
+ private:
+    int write_site(const CSLocus* cloc, const LocPopSum* psum, Datum const*const* datums, size_t col, size_t index);
+};
+
 class FastaLociExport: public Export {
     //
     // Output a list of heterozygous loci and the associated haplotype frequencies.
@@ -391,6 +430,19 @@ class VcfHapsExport: public Export {
     int write_header() { return 0; }
 };
 
+class TreemixExport: public OrderableExport {
+    const MetaPopInfo*_mpopi;
+    ofstream _writer;
+
+ public:
+    TreemixExport() : _mpopi(NULL), _writer(NULL) {}
+    int open(const MetaPopInfo *mpopi);
+    int write_header() { return 0; }
+
+ private:
+    int write_site(const CSLocus* cloc, const LocPopSum* psum, Datum const*const* datums, size_t col, size_t index);
+};
+
 /*
 int write_generic(map<int, CSLocus *> &, PopMap<CSLocus> *, bool);
 int write_vcf_haplotypes(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
@@ -398,7 +450,6 @@ int write_phase(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
 int write_fastphase(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
 int write_plink(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
 int write_hzar(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
-int write_treemix(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
 int write_fullseq_phylip(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *);
 */
 
