@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2012-2017, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2012-2019, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -104,7 +104,7 @@ class CatalogDists {
     map<size_t, size_t> _pre_snps_per_loc, _post_snps_per_loc;
 
 public:
-    int accumulate_pre_filtering(const CSLocus *);
+    int accumulate_pre_filtering(const size_t, const CSLocus *);
     int accumulate(const vector<LocBin *> &);
     int write_results(ostream &log_fh);
 };
@@ -130,7 +130,7 @@ public:
         this->_ord_ss = new OSumStat<SumStat>(log_fh);
         this->_ks_ls  = new KSmooth<LocStat>(2);
         this->_ord_ls = new OHaplotypes<LocStat>();
-        this->_ks_hs  = new KSmooth<HapStat>(5);
+        this->_ks_hs  = new KSmooth<HapStat>(6);
         this->_ord_hs = new OHaplotypes<HapStat>();
         this->_ks_pp  = new KSmooth<PopPair>(2);
         this->_ord_pp = new OPopPair<PopPair>(log_fh);
@@ -162,7 +162,6 @@ public:
         this->_sample_cnt = 0;
         this->_pop_order  = NULL; // The array order of each population.
         this->_samples    = NULL; // Which population each sample belongs to.
-        this->_pop_cnts   = NULL; // For a locus, how many samples are present in each population.
         this->_pop_tot    = NULL; // The total number of samples in each population.
         this->_filtered_loci       = 0;
         this->_total_loci          = 0;
@@ -183,8 +182,6 @@ public:
             delete [] this->_pop_order;
         if (this->_samples != NULL)
             delete [] this->_samples;
-        if (this->_pop_cnts != NULL)
-            delete [] this->_pop_cnts;
         if (this->_pop_tot != NULL)
             delete [] this->_pop_tot;
     }
@@ -198,12 +195,15 @@ public:
     void   init(MetaPopInfo *mpopi);
     bool   whitelist_filter(size_t locus_id);
     bool   blacklist_filter(size_t locus_id);
-    bool   filter(MetaPopInfo *mpopi, Datum **d);
+    void   whitelist_snp_filter(LocBin& loc) const;
+    bool   apply_filters_stacks(LocBin& loc, ostream& log_fh, const MetaPopInfo& mpopi);
+    bool   apply_filters_external(LocBin& loc, ostream& log_fh, const MetaPopInfo& mpopi);
+    bool   filter(const MetaPopInfo *mpopi, Datum **d, CSLocus *cloc);
+    void   filter_snps(LocBin& loc, const MetaPopInfo& mpopi, ostream &log_fh);
+    void   filter_haps(LocBin& loc, const MetaPopInfo& mpopi, ostream &log_fh);
     void   gt_depth_filter(Datum **d, const CSLocus *cloc);
-    int    keep_single_snp(const CSLocus *cloc, const LocTally *t);
-    int    keep_random_snp(const CSLocus *cloc, const LocTally *t);
-    int    prune_sites_with_whitelist(MetaPopInfo *mpopi, CSLocus *cloc, Datum **d, bool user_wl);
-    bool   prune_sites_with_filters(MetaPopInfo *mpopi, CSLocus *cloc, Datum **d, LocPopSum *s, ostream &log_fh);
+    void   keep_single_snp(CSLocus* cloc, Datum** d, size_t n_samples, const LocTally* t) const;
+    void   keep_random_snp(CSLocus* cloc, Datum** d, size_t n_samples, const LocTally* t) const;
 
     size_t filtered()       const { return this->_filtered_loci; }
     size_t total()          const { return this->_total_loci; }
@@ -223,11 +223,12 @@ public:
     const map<int, set<int>>&  whitelist() { return this->_whitelist; }
 
 private:
+    static void erase_snp(CSLocus *cloc, Datum **d, size_t n_samples, size_t snp_index);
+
     size_t  _pop_cnt;
     size_t  _sample_cnt;
     size_t *_pop_order;
     size_t *_samples;
-    size_t *_pop_cnts;
     size_t *_pop_tot;
     size_t  _filtered_loci;
     size_t  _total_loci;
@@ -241,9 +242,6 @@ private:
 
     set<int>           _blacklist;
     map<int, set<int>> _whitelist;
-
-    void reset();
-    int  prune_sites(CSLocus *, Datum **, set<int> &);
 };
 
 //
@@ -255,13 +253,13 @@ class BatchLocusProcessor {
 public:
     BatchLocusProcessor():
         _input_mode(InputMode::stacks2), _user_supplied_whitelist(false), _batch_size(0), _batch_num(0),
-        _mpopi(NULL), _next_loc(NULL), _unordered_bp(1) {}
+        _mpopi(NULL), _next_loc(NULL), _unordered_bp(0) {}
     BatchLocusProcessor(InputMode mode, size_t batch_size, MetaPopInfo *popi):
         _input_mode(mode), _user_supplied_whitelist(false), _batch_size(batch_size), _batch_num(0),
-        _mpopi(popi), _next_loc(NULL), _unordered_bp(1) {}
+        _mpopi(popi), _next_loc(NULL), _unordered_bp(0) {}
     BatchLocusProcessor(InputMode mode, size_t batch_size):
         _input_mode(mode), _user_supplied_whitelist(false), _batch_size(batch_size), _batch_num(0),
-        _mpopi(NULL), _next_loc(NULL), _unordered_bp(1) {}
+        _mpopi(NULL), _next_loc(NULL), _unordered_bp(0) {}
     ~BatchLocusProcessor() {
         for (uint i = 0; i < this->_loci.size(); i++)
             delete this->_loci[i];
@@ -337,7 +335,6 @@ void    open_log(ofstream &);
 int     build_file_list();
 int     load_marker_list(string, set<int> &);
 int     load_marker_column_list(string, map<int, set<int> > &);
-int     log_haplotype_cnts(map<int, CSLocus *> &, ofstream &);
 //int     merge_shared_cutsite_loci(map<int, CSLocus *> &, PopMap<CSLocus> *, PopSum<CSLocus> *, map<int, pair<merget, int> > &, ofstream &);
 phaset  merge_and_phase_loci(PopMap<CSLocus> *, CSLocus *, CSLocus *, set<int> &, ofstream &);
 int     merge_datums(int, int, Datum **, Datum **, set<string> &, int);
